## Simple diagram
```python linenums="1"
--8<-- "simple_rbd.py:14:14,17:"
```

--8<-- "simple_rbd.py:4:8"

<img width="500" src='examples/simple_RBD.svg'/>


## Example with more functionality

```python linenums="1"
--8<-- "example_rbd.py:17:21,24:"
```

--8<-- "example_rbd.py:4:11"

<img width="1000" src='examples/example_RBD.svg'/>


## Layered `Series` and `Group` instances

```python linenums="1"
--8<-- "layered_rbd.py:7:7,10:"
```

<img width="1200" src='examples/layered_RBD.svg'/>
